@@ -8,9 +8,9 @@ from zipfile import ZipFile
 
 import pytest
 
+from instawow import __version__
 from instawow.config import Config, Flavour
 from instawow.manager import Manager, init_web_client
-from instawow.utils import get_version
 
 inf = float('inf')
 
@@ -61,25 +61,36 @@ def make_addon_zip(*folders):
 
 @pytest.fixture(scope='session', autouse=True)
 def iw_temp_dir(tmp_path_factory):
-    temp_dir = os.environ['INSTAWOW_TEMP_DIR'] = str(tmp_path_factory.mktemp('temp'))
+    temp_dir = tmp_path_factory.mktemp('temp')
+    os.environ['INSTAWOW_TEMP_DIR'] = str(temp_dir)
     yield temp_dir
 
 
-@pytest.fixture(params=Flavour)
-def iw_partial_config(tmp_path, request, iw_temp_dir):
+@pytest.fixture(
+    params=[
+        Flavour.retail,
+        Flavour.vanilla_classic,
+    ]
+)
+def iw_config_dict_no_config_dir(tmp_path, request, iw_temp_dir):
     addons = tmp_path / 'wow' / 'interface' / 'addons'
     addons.mkdir(parents=True)
-    return {'addon_dir': addons, 'temp_dir': iw_temp_dir, 'game_flavour': request.param}
+    return {
+        'profile': '__default__',
+        'addon_dir': addons,
+        'temp_dir': iw_temp_dir,
+        'game_flavour': request.param,
+    }
 
 
 @pytest.fixture
-def iw_full_config(tmp_path, iw_partial_config):
-    return {**iw_partial_config, 'config_dir': tmp_path / 'config'}
+def iw_config_dict(tmp_path, iw_config_dict_no_config_dir):
+    return {**iw_config_dict_no_config_dir, 'config_dir': tmp_path / 'config'}
 
 
 @pytest.fixture
-def iw_config(iw_full_config):
-    yield Config(**iw_full_config).write()
+def iw_config(iw_config_dict):
+    yield Config(**iw_config_dict).write()
 
 
 @pytest.fixture
@@ -102,7 +113,7 @@ def mock_pypi(aresponses):
         'pypi.org',
         '/pypi/instawow/json',
         'get',
-        {'info': {'version': get_version()}},
+        {'info': {'version': __version__}},
         repeat=inf,
     )
 
@@ -213,6 +224,14 @@ def mock_tukui(aresponses, mock_master_catalogue):
         match_querystring=True,
         repeat=inf,
     )
+    aresponses.add(
+        'www.tukui.org',
+        '/api.php?classic-tbc-addons=all',
+        'get',
+        load_json_fixture('tukui-classic-tbc-addons.json'),
+        match_querystring=True,
+        repeat=inf,
+    )
     aresponses.add(
         'www.tukui.org',
         '/api.php',
@@ -237,7 +256,7 @@ def mock_tukui(aresponses, mock_master_catalogue):
     )
     aresponses.add(
         'www.tukui.org',
-        '/classic-addons.php?download=1',
+        re.compile(r'/classic-(?:-tbc)?addons\.php\?download=1'),
         'get',
         aresponses.Response(body=make_addon_zip('Tukui')),
         match_querystring=True,
@@ -248,25 +267,46 @@ def mock_tukui(aresponses, mock_master_catalogue):
 @pytest.fixture
 @should_mock
 def mock_github(aresponses):
+    aresponses.add(
+        'api.github.com',
+        '/repos/nebularg/PackagerTest',
+        'get',
+        load_json_fixture('github-repo-release-json.json'),
+        repeat=inf,
+    )
+    aresponses.add(
+        'api.github.com',
+        '/repos/nebularg/PackagerTest/releases/latest',
+        'get',
+        load_json_fixture('github-release-release-json.json'),
+        repeat=inf,
+    )
+    aresponses.add(
+        'github.com',
+        '/nebularg/PackagerTest/releases/download/v1.9.6/release.json',
+        'get',
+        load_json_fixture('github-release-release-json-release-json.json'),
+        repeat=inf,
+    )
     aresponses.add(
         'api.github.com',
         '/repos/AdiAddons/AdiButtonAuras',
         'get',
-        load_json_fixture('github-repo-lib-and-nolib.json'),
+        load_json_fixture('github-repo-legacy-lib-and-nolib.json'),
         repeat=inf,
     )
     aresponses.add(
         'api.github.com',
         '/repos/AdiAddons/AdiButtonAuras/releases/latest',
         'get',
-        load_json_fixture('github-release-lib-and-nolib.json'),
+        load_json_fixture('github-release-legacy-lib-and-nolib.json'),
         repeat=inf,
     )
     aresponses.add(
         'api.github.com',
         '/repos/AdiAddons/AdiButtonAuras/releases?per_page=1',
         'get',
-        [load_json_fixture('github-release-lib-and-nolib.json')],
+        [load_json_fixture('github-release-legacy-lib-and-nolib.json')],
         match_querystring=True,
         repeat=inf,
     )
@@ -274,34 +314,34 @@ def mock_github(aresponses):
         'api.github.com',
         '/repos/AdiAddons/AdiButtonAuras/releases/tags/2.1.0',
         'get',
-        load_json_fixture('github-release-lib-and-nolib-older-version.json'),
-        repeat=inf,
-    )
-    aresponses.add(
-        'api.github.com',
-        '/repos/WeakAuras/WeakAuras2',
-        'get',
-        load_json_fixture('github-repo-retail-and-classic.json'),
-        repeat=inf,
-    )
-    aresponses.add(
-        'api.github.com',
-        '/repos/WeakAuras/WeakAuras2/releases/latest',
-        'get',
-        load_json_fixture('github-release-retail-and-classic.json'),
+        load_json_fixture('github-release-legacy-lib-and-nolib-older-version.json'),
         repeat=inf,
     )
     aresponses.add(
         'api.github.com',
         '/repos/p3lim-wow/Molinari',
         'get',
-        load_json_fixture('github-repo-no-releases.json'),
+        load_json_fixture('github-repo-legacy-retail-and-classic.json'),
         repeat=inf,
     )
     aresponses.add(
         'api.github.com',
         '/repos/p3lim-wow/Molinari/releases/latest',
         'get',
+        load_json_fixture('github-release-legacy-retail-and-classic.json'),
+        repeat=inf,
+    )
+    aresponses.add(
+        'api.github.com',
+        '/repos/AdiAddons/AdiBags',
+        'get',
+        load_json_fixture('github-repo-no-releases.json'),
+        repeat=inf,
+    )
+    aresponses.add(
+        'api.github.com',
+        '/repos/AdiAddons/AdiBags/releases/latest',
+        'get',
         aresponses.Response(body=b'', status=404),
         repeat=inf,
     )
@@ -314,7 +354,7 @@ def mock_github(aresponses):
     )
     aresponses.add(
         'api.github.com',
-        '/repos/layday/foo-bar',
+        '/repos/layday/foobar',
         'get',
         aresponses.Response(body=b'', status=404),
         repeat=inf,
