@@ -1,7 +1,11 @@
+from pathlib import Path
+
 from aiohttp import ClientError
 import pytest
 
-from instawow import results as E
+from instawow import results as R
+from instawow.config import Flavour
+from instawow.models import Pkg
 from instawow.resolvers import Defn, Strategy
 
 
@@ -27,7 +31,7 @@ async def test_pinning_unsupported_pkg(iw_manager):
     assert installed_pkg.options.strategy == Strategy.default
     result = await iw_manager.pin([molinari_defn])
     assert (
-        type(result[molinari_defn]) is E.PkgStrategyUnsupported
+        type(result[molinari_defn]) is R.PkgStrategyUnsupported
         and result[molinari_defn].strategy is Strategy.version
     )
     assert installed_pkg.options.strategy == Strategy.default
@@ -37,7 +41,7 @@ async def test_pinning_unsupported_pkg(iw_manager):
 async def test_pinning_nonexistent_pkg(iw_manager):
     molinari_defn = Defn('wowi', '13188')
     result = await iw_manager.pin([molinari_defn])
-    assert type(result[molinari_defn]) is E.PkgNotInstalled
+    assert type(result[molinari_defn]) is R.PkgNotInstalled
 
 
 @pytest.mark.parametrize('exception', [ValueError('foo'), ClientError('bar')])
@@ -52,7 +56,7 @@ async def test_resolve_rewraps_exception_appropriately_from_resolve(
 
     defn = Defn('curse', 'molinari')
     results = await iw_manager.resolve([defn])
-    assert type(results[defn]) is E.InternalError
+    assert type(results[defn]) is R.InternalError
     assert results[defn].message == f'internal error: "{exception}"'
 
 
@@ -68,10 +72,25 @@ async def test_resolve_rewraps_exception_appropriately_from_batch_resolve(
 
     defn = Defn('curse', 'molinari')
     results = await iw_manager.resolve([defn])
-    assert type(results[defn]) is E.InternalError
+    assert type(results[defn]) is R.InternalError
     assert results[defn].message == f'internal error: "{exception}"'
 
 
+@pytest.mark.asyncio
+async def test_resolve_invalid_source(iw_manager):
+    defn = Defn('bar', 'baz')
+    results = await iw_manager.resolve([defn])
+    assert type(results[defn]) is R.PkgSourceInvalid
+
+
+@pytest.mark.asyncio
+async def test_resolve_plugin_hook_source(iw_manager):
+    pytest.importorskip('instawow_test_plugin')
+    defn = Defn('me', 'bar')
+    results = await iw_manager.resolve([defn])
+    assert type(results[defn]) is Pkg
+
+
 @pytest.mark.asyncio
 async def test_install_can_replace_unreconciled_folders(iw_manager):
     molinari = iw_manager.config.addon_dir / 'Molinari'
@@ -80,11 +99,11 @@ async def test_install_can_replace_unreconciled_folders(iw_manager):
     defn = Defn('curse', 'molinari')
 
     result = await iw_manager.install([defn], replace=False)
-    assert type(result[defn]) is E.PkgConflictsWithUnreconciled
+    assert type(result[defn]) is R.PkgConflictsWithUnreconciled
     assert not any(molinari.iterdir())
 
     result = await iw_manager.install([defn], replace=True)
-    assert type(result[defn]) is E.PkgInstalled
+    assert type(result[defn]) is R.PkgInstalled
     assert any(molinari.iterdir())
 
 
@@ -94,13 +113,13 @@ async def test_install_cannot_replace_reconciled_folders(iw_manager):
     wowi_defn = Defn('wowi', '13188-molinari')
 
     result = await iw_manager.install([curse_defn], replace=False)
-    assert type(result[curse_defn]) is E.PkgInstalled
+    assert type(result[curse_defn]) is R.PkgInstalled
 
     result = await iw_manager.install([wowi_defn], replace=False)
-    assert type(result[wowi_defn]) is E.PkgConflictsWithInstalled
+    assert type(result[wowi_defn]) is R.PkgConflictsWithInstalled
 
     result = await iw_manager.install([wowi_defn], replace=True)
-    assert type(result[wowi_defn]) is E.PkgConflictsWithInstalled
+    assert type(result[wowi_defn]) is R.PkgConflictsWithInstalled
 
 
 @pytest.mark.asyncio
@@ -109,27 +128,27 @@ async def test_update_lifecycle_while_varying_retain_strategy(iw_manager):
     versioned_defn = defn.with_version('80000.57-Release')
 
     result = await iw_manager.install([defn], replace=False)
-    assert type(result[defn]) is E.PkgInstalled
+    assert type(result[defn]) is R.PkgInstalled
     assert result[defn].pkg.options.strategy == Strategy.default
 
     result = await iw_manager.update([defn], retain_strategy=False)
-    assert type(result[defn]) is E.PkgUpToDate
+    assert type(result[defn]) is R.PkgUpToDate
     assert result[defn].is_pinned is False
 
     result = await iw_manager.update([versioned_defn], retain_strategy=False)
-    assert type(result[versioned_defn]) is E.PkgUpToDate
+    assert type(result[versioned_defn]) is R.PkgUpToDate
     assert result[versioned_defn].is_pinned is False
 
     result = await iw_manager.update([versioned_defn], retain_strategy=True)
-    assert type(result[versioned_defn]) is E.PkgUpdated
+    assert type(result[versioned_defn]) is R.PkgUpdated
     assert result[versioned_defn].new_pkg.options.strategy == Strategy.version
 
     result = await iw_manager.update([defn], retain_strategy=False)
-    assert type(result[defn]) is E.PkgUpToDate
+    assert type(result[defn]) is R.PkgUpToDate
     assert result[defn].is_pinned is True
 
     result = await iw_manager.update([defn], retain_strategy=True)
-    assert type(result[defn]) is E.PkgUpdated
+    assert type(result[defn]) is R.PkgUpdated
     assert result[defn].new_pkg.options.strategy == Strategy.default
 
 
@@ -143,7 +162,7 @@ async def test_deleting_and_retaining_folders_on_remove(iw_manager, keep_folders
     assert all(f.is_dir() for f in folders)
 
     result = await iw_manager.remove([defn], keep_folders=keep_folders)
-    assert type(result[defn]) is E.PkgRemoved
+    assert type(result[defn]) is R.PkgRemoved
     assert not iw_manager.get_pkg(defn)
     if keep_folders:
         assert all(f.is_dir() for f in folders)
@@ -156,14 +175,14 @@ async def test_deleting_and_retaining_folders_on_remove(iw_manager, keep_folders
 async def test_removing_pkg_with_missing_folders(iw_manager, keep_folders):
     defn = Defn('curse', 'molinari')
 
-    await iw_manager.install([defn], False)
-    folders = [iw_manager.config.addon_dir / f.name for f in iw_manager.get_pkg(defn).folders]
+    result = await iw_manager.install([defn], False)
+    folders = [iw_manager.config.addon_dir / f.name for f in result[defn].pkg.folders]
     for folder in folders:
         folder.rename(folder.with_name(f'Not_{folder.name}'))
     assert not any(f.is_dir() for f in folders)
 
     result = await iw_manager.remove([defn], keep_folders=keep_folders)
-    assert type(result[defn]) is E.PkgRemoved
+    assert type(result[defn]) is R.PkgRemoved
     assert not iw_manager.get_pkg(defn)
 
 
@@ -186,19 +205,19 @@ async def test_search_source_filtering(iw_manager):
 async def test_search_caters_to_flavour(iw_manager):
     results = await iw_manager.search('AtlasLootClassic', limit=5)
     defns = {Defn(e.source, e.slug or e.id) for e in results}
-    if iw_manager.config.is_classic:
+    if iw_manager.config.game_flavour is Flavour.vanilla_classic:
         assert Defn('curse', 'atlaslootclassic') in defns
     else:
         assert Defn('curse', 'atlaslootclassic') not in defns
 
 
 @pytest.mark.asyncio
-async def test_get_changelog_from_empty_data(iw_manager):
+async def test_get_changelog_from_empty_data_url(iw_manager):
     assert (await iw_manager.get_changelog('data:,')) == ''
 
 
 @pytest.mark.asyncio
-async def test_get_changelog_from_url_encoded_data(iw_manager):
+async def test_get_changelog_from_url_encoded_data_url(iw_manager):
     assert (await iw_manager.get_changelog('data:,foo%20bar')) == 'foo bar'
 
 
@@ -209,7 +228,16 @@ async def test_get_malformed_changelog(iw_manager):
 
 
 @pytest.mark.asyncio
-async def test_get_changelog_from_url(iw_manager):
+async def test_get_changelog_from_file_uri(iw_manager):
+    assert (
+        await iw_manager.get_changelog(
+            (Path(__file__).parent / 'fixtures' / 'curse-addon-changelog.txt').as_uri()
+        )
+    ).startswith('<h3>Changes in 90000.73-Release:</h3>')
+
+
+@pytest.mark.asyncio
+async def test_get_changelog_from_web_url(iw_manager):
     assert (
         await iw_manager.get_changelog(
             'https://addons-ecs.forgesvc.net/api/v2/addon/20338/file/3152268/changelog'
